size(256, 256)

scale(0.5, 0.5)
p = "../images/drawbot.png"

blendMode("multiply")
image(p, (0, 0))
image(p, (100, 100))
